Examples
********

.. toctree::
   :maxdepth: 1

   validation_framework
   temporal_collocation
   anomalies
   triple_collocation
   compare_ASCAT_ISMN
   swi_calc

All shown examples are also available as ipython notebooks in ``pytesmo/docs/examples``.
Some of the examples require the packages `ascat` and `ismn`, which can be installed with `pip`.
